==> lpmn_client_biz-2.0.5-py3-none-any.whl: lpmn_client_biz/connection.py <==
"""Connection class implementation."""
import os
from enum import Enum

import requests
from pyaml_env import parse_config

USERNAME = 'USERNAME'
PASSWORD = 'PASSWORD'

requests.packages.urllib3.disable_warnings(
    requests.packages.urllib3.exceptions.InsecureRequestWarning)


class IOType(Enum):
    """Enum type for input types."""

    TEXT = "text"
    FILE = "file"
    FILE_ID = "file_id"

    def __str__(self):
        """To string for IOType Enum."""
        return self.name.lower()

    def __repr__(self):
        """String representation for IOType Enum."""
        return str(self)

    @staticmethod
    def argparse(s):
        """Argument parsing for argparser type."""
        try:
            return IOType[s.upper()]
        except KeyError:
            return s


class Connection:
    """Implementation of Connection class."""

    BASE_API_URL = "https://services-test.clarin-pl.eu/api/v1"
    API_ENDPOINTS = {
        "login": "/oauth/login",
        "files": "/files/",
        "tasks": {"start": "/tasks/",
                  "run": "/tasks/run/",
                  "progress": "/tasks/",
                  "sent": "/tasks/sent/",
                  "status": "/tasks/users/",
                  "cancel": "/tasks/cancel/"}
    }
    LOCAL_CONFIG = 'config.yml'

    def __init__(self, username='', password='',
                 baseurl='', config_file='') -> None:
        """Configure connection authorization with api.

        :param username: e-science username
        :type username: str
        :param password: e-science user password
        :type password: str
        :param baseurl: base api url if different from default
        :type baseurl: str
        :param config_file: path of user config file with username and password
        :type config_file: str
        """
        if os.name == "nt":  # Windows
            base_dir = os.getenv('LOCALAPPDATA') if \
                os.getenv('LOCALAPPDATA') else os.getenv('APPDATA')
        else:
            base_dir = os.path.expanduser('~')
        if base_dir:
            user_config = os.path.join(base_dir, '.clarin', "config.yml")

        self.token = None
        self.base_url = baseurl if baseurl else Connection.BASE_API_URL

        if username and password:
            self.token = self.__get_api_token(username, password)
        elif config_file:
            self.__parse_config(config_file)
        elif os.path.isfile(Connection.LOCAL_CONFIG):
            self.__parse_config(Connection.LOCAL_CONFIG)
        elif base_dir and os.path.isfile(user_config):
            self.__parse_config(user_config)

        if self.token is None:
            raise Exception('Authorization Error')

    def __parse_config(self, config_file):
        config = parse_config(config_file)
        if USERNAME in config and PASSWORD in config:
            self.token = self.__get_api_token(config[USERNAME],
                                              config[PASSWORD])

    def __get_api_token(self, username: str, password: str):
        r = requests.post(
            url=f"{self.base_url}{Connection.API_ENDPOINTS['login']}",
            json={
                "username": username,
                "password": password
            },
            verify=False
        )
        if r.status_code == 200:
            data = r.json()
            return data["access_token"]

==> lpmn_client_biz-2.0.6-py3-none-any.whl: lpmn_client_biz/connection.py <==
"""Connection class implementation."""
import os
from enum import Enum
from glob import glob

import requests
from pyaml_env import parse_config

USERNAME = 'USERNAME'
PASSWORD = 'PASSWORD'
CONFIG_REGX = 'config*.y*ml'
DOT_CLARIN = '.clarin'
ACCESS_TOKEN = 'access_token'

requests.packages.urllib3.disable_warnings(
    requests.packages.urllib3.exceptions.InsecureRequestWarning)


class IOType(Enum):
    """Enum type for input types."""

    TEXT = "text"
    FILE = "file"
    FILE_ID = "file_id"

    def __str__(self):
        """To string for IOType Enum."""
        return self.name.lower()

    def __repr__(self):
        """String representation for IOType Enum."""
        return str(self)

    @staticmethod
    def argparse(s):
        """Argument parsing for argparser type."""
        try:
            return IOType[s.upper()]
        except KeyError:
            return s


class Connection:
    """Implementation of Connection class."""

    BASE_API_URL = "https://services-test.clarin-pl.eu/api/v1"
    API_ENDPOINTS = {
        "login": "/oauth/login",
        "files": "/files/",
        "tasks": {"start": "/tasks/",
                  "run": "/tasks/run/",
                  "progress": "/tasks/",
                  "sent": "/tasks/sent/",
                  "status": "/tasks/users/",
                  "cancel": "/tasks/cancel/"}
    }

    def __init__(self, username='', password='',
                 baseurl='', config_file='') -> None:
        """Configure connection authorization with api.

        :param username: e-science username
        :type username: str
        :param password: e-science user password
        :type password: str
        :param baseurl: base api url if different from default
        :type baseurl: str
        :param config_file: path of user config file with username and password
        :type config_file: str
        """
        if os.name == "nt":  # Windows
            base_dir = os.getenv('LOCALAPPDATA') if \
                os.getenv('LOCALAPPDATA') else os.getenv('APPDATA')
        else:
            base_dir = os.path.expanduser('~')

        if os.path.isfile(config_file):
            user_config = config_file
        else:
            config = Connection.__get_glob_config(CONFIG_REGX)
            if os.path.isfile(config):
                user_config = config
            else:
                user_config = Connection.__get_glob_config(
                    os.path.join(base_dir, DOT_CLARIN, CONFIG_REGX))

        self.token = None
        self.base_url = baseurl if baseurl else Connection.BASE_API_URL

        if username and password:
            self.token, info = self.__get_api_token(username, password)
        elif os.path.isfile(user_config):
            self.token, info = self.__parse_config(user_config)

        if self.token is None:
            raise Exception(f'Authorization Error, {info}')

    def __parse_config(self, config_file):
        config = parse_config(config_file)
        if USERNAME in config and PASSWORD in config:
            return self.__get_api_token(config[USERNAME],
                                        config[PASSWORD])
        else:
            return None, f'{USERNAME} or {PASSWORD} not present ' \
                         f'in config file on path {config_file}'

    def __get_api_token(self, username: str, password: str):
        r = requests.post(
            url=f"{self.base_url}{Connection.API_ENDPOINTS['login']}",
            json={
                "username": username,
                "password": password
            },
            verify=False
        )
        if r.status_code == 200:
            data = r.json()
            return data[ACCESS_TOKEN], 'OK'
        return None, 'Invalid credentials'

    @staticmethod
    def __get_glob_config(path):
        config = glob(path)
        config = config[0] if len(config) > 0 else ''
        return config
